package com.springboot.mongodb.bootstrap;

import com.github.javafaker.Faker;
import com.springboot.mongodb.entity.Employee;
import com.springboot.mongodb.service.DbSequenceGenr;
import com.springboot.mongodb.service.EmployeeService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Component;

import java.util.Random;

// Lombok annotation for logger
@Slf4j
// Spring annotation
@Component
public class DefaultEmployeesLoader implements CommandLineRunner {

    private static final String[] GENDER = {"Male", "Female", "Transgender"};
    private static final Random RANDOM = new Random();

    @Autowired
    private EmployeeService service;
    @Autowired
    private DbSequenceGenr sequenceGenr;
    @Autowired
    private Faker faker;

    // will add the dummy employee data in the mongodb collection
    // will be invoked automatically on the application startup
    @Override
    public void run(String... args) {
        if (service.getCollectionCount() == 0) {
            log.info("Saving default employees in the collection");
            for (int i=0; i<11; i++) {
                persist();
            }
        } else {
            log.info("Default employees are already present in the mongo collection");
        }
    }

    // calls the service layer method which in turn calls the dao layer method
    // to save the employee record in the mongodb collection
    private void persist() {
        final Employee e = createEmployee();
        service.save(e);
    }

    // using the faker library to create some mock data for the employee model
    private Employee createEmployee() {
        final String firstName = faker.name().firstName();
        final String lastName = faker.name().lastName();
        final String gender = GENDER[RANDOM.nextInt(GENDER.length)];
        final String email = firstName.toLowerCase() + "." + lastName.toLowerCase() + "@automation.com";

        return Employee.builder()
                .id(sequenceGenr.getNextSequence(Employee.SEQUENCE_NUMBER))
                .firstName(firstName)
                .lastName(lastName)
                .gender(gender)
                .email(email)
                .phoneNumber(faker.phoneNumber().cellPhone())
                .homeAddress(faker.address().fullAddress())
                .build();
    }
}
